
import { useAjax } from '@/Hook/useAjax'
import { PromotedObjectType } from '@/services/launchAdq/enum'
import { Col, Row, Input, Select, message } from 'antd'
import React, { useEffect, useCallback } from 'react'
import TableData from '../../components/TableData'
import tableConfig from './tableConfig'
import { putAdqAdgroupsSync, getAdqAdgroupsList,putAdqAdgroupsConfigStatus } from '@/services/launchAdq/adq'
type Props = {
    accountId: string,
    adAccountId: string,
    userId: string,
    queryParmas: {
        accountId?: string,//账户ID
        campaignId?: string,//计划ID
        adgroupId?: string,//广告ID
        adcreativeId?: string,//创意ID
        pageId?: string,//落地页ID
        targetingId?: string,//定向ID}
    },
    tableIdClick: (props: {
        activeKey: string, parma: {
            accountId?: string,//账户ID
            campaignId?: string,//计划ID
            adgroupId?: string,//广告ID
            adcreativeId?: string,//创意ID
            pageId?: string,//落地页ID
            targetingId?: string,//定向ID
        }
    }) => void
}

function Ad(props:Props) {
    let { accountId, adAccountId,userId,tableIdClick,queryParmas } = props
    // api方法
    const listAjax = useAjax((params) => getAdqAdgroupsList(params), { formatResult: true })
    const syncAjax = useAjax((adAccountId) => putAdqAdgroupsSync(adAccountId))
    const switchAjax = useAjax((params) => putAdqAdgroupsConfigStatus(params))
    console.log('创意=====》')
    useEffect(() => {
        getList({ pageNum: 1, pageSize: 20,...queryParmas })
    }, [accountId,userId,queryParmas])
    // 获取列表
    const getList = useCallback((params: {
        pageNum: number;
        pageSize: number;
        accountId?: string;
        adcreativeName?: string;
        adgroupId?:string
    }) => {
        if (!params.adcreativeName || params.adcreativeName !== listAjax?.params[0]?.adcreativeName) {
            !params.adcreativeName && delete params.adcreativeName
            listAjax.run({ ...params,userId, accountId })
        }
    }, [accountId,userId,listAjax])
    // 同步 
    const sync = useCallback(() => {
        if(!adAccountId){
            message.error('请先选择要同步的广点通账号!')
            return
        }
        syncAjax.run({adAccountId}).then(res => {
            res && listAjax.refresh()
            res ? message.success('同步成功！') : message.error('同步失败！')

        })
    }, [adAccountId, listAjax])
    // 启停
    const switchHandle=useCallback((data,checked)=>{
        let { accountId,adgroupId}=data
        console.log(checked)
        let configuredStatus = checked ? 'AD_STATUS_NORMAL' : 'AD_STATUS_SUSPEND'
        switchAjax.run({accountId,adgroupId,configuredStatus}).then(res=>{
            res && listAjax.refresh()
            res ? message.success(checked?'开启广告成功！':'关闭广告成功！') : message.error(checked?'开启广告失败':'关闭广告失败！')
        })
    },[])
    return <div>
        <TableData
            columns={()=>tableConfig(switchHandle,tableIdClick)}
            ajax={listAjax}
            syncAjax={sync}
            dataSource={listAjax?.data?.data?.records}
            loading={listAjax?.loading || syncAjax?.loading}
            scroll={{ x: 2500,y:550 }}
            total={listAjax?.data?.data?.total}
            page={listAjax?.data?.data?.current}
            pageSize={listAjax?.data?.data?.size}
            myKey={'adgroupId'}
            leftChild={<>
                <Row gutter={[10, 10]}>
                    <Col>
                        <Input
                            placeholder='广告名称'
                            allowClear
                            onBlur={(e) => {
                                let value = e.target.value
                                getList({ pageNum: 1, pageSize: 20, adcreativeName: value })
                            }}
                            onKeyDownCapture={(e: any) => {
                                let key = e.key
                                if (key === 'Enter') {
                                    let value = e.target.value
                                    getList({ pageNum: 1, pageSize: 20, adcreativeName: value })
                                }
                            }}
                            onChange={(e) => {
                                let value = e.target.value
                                if (!value) {
                                    getList({ pageNum: 1, pageSize: 20, adcreativeName: value })
                                }
                            }}
                        />
                    </Col>
                    <Col>
                        <Input
                            placeholder='广告ID'
                            allowClear
                            onBlur={(e) => {
                                let value = e.target.value
                                getList({ pageNum: 1, pageSize: 20, adgroupId: value })
                            }}
                            onKeyDownCapture={(e: any) => {
                                let key = e.key
                                if (key === 'Enter') {
                                    let value = e.target.value
                                    getList({ pageNum: 1, pageSize: 20, adgroupId: value })
                                }
                            }}
                            onChange={(e) => {
                                let value = e.target.value
                                if (!value) {
                                    getList({ pageNum: 1, pageSize: 20, adgroupId: value })
                                }
                            }}
                        />
                    </Col>
                    <Col>
                        <Select placeholder='推广目标选择' style={{ minWidth: 200 }} showSearch filterOption={(input: any, option: any) =>
                            (option!.children as unknown as string).toLowerCase().includes(input.toLowerCase())
                        } allowClear onChange={(value: any) => {
                            getList({ pageNum: 1, pageSize: 20, accountId })
                        }}>
                            {
                                Object.keys(PromotedObjectType).map(key => {
                                    // let obj = JSON.parse(PromotedObjectType[key])
                                    return <Select.Option value={key} key={key}>{PromotedObjectType[key]}</Select.Option>
                                })
                            }
                        </Select>
                    </Col>
                </Row>
            </>}
            onChange={(props: any) => {
                let { sortData, pagination } = props
                let { current, pageSize } = pagination
                getList({ pageNum: current, pageSize })
            }}
        />
    </div>
}
export default Ad